# Annalist_schema

This is an Annalist collection which describes terms in the Annalist (`annal:`) namespace.

It uses definitions from collection `RDF_schema_defs`.

The values described here are thjose that appear in the ANNAL namespace in `src/annalist_root/annalist/identifiers.py`.

